[Bedework-commit] r370 - branches/REL-3.0/calendar3/calCore/src/org/bedework/calcore/hibernate

svnadmin at bedework.org svnadmin at bedework.org
Thu Apr 13 11:12:42 EDT 2006


Author: douglm
Date: 2006-04-13 11:12:41 -0400 (Thu, 13 Apr 2006)
New Revision: 370

Modified:
   branches/REL-3.0/calendar3/calCore/src/org/bedework/calcore/hibernate/Calendars.java
Log:
Fix access check for calendars - prevented add calendar



Modified: branches/REL-3.0/calendar3/calCore/src/org/bedework/calcore/hibernate/Calendars.java
===================================================================
--- branches/REL-3.0/calendar3/calCore/src/org/bedework/calcore/hibernate/Calendars.java	2006-04-13 13:35:10 UTC (rev 369)
+++ branches/REL-3.0/calendar3/calCore/src/org/bedework/calcore/hibernate/Calendars.java	2006-04-13 15:12:41 UTC (rev 370)
@@ -308,8 +308,8 @@
   public void addCalendar(BwCalendar val, BwCalendar parent) throws CalFacadeException {
     HibSession sess = getSess();
 
-    /* We need write access to the parent */
-    access.accessible(parent, privWrite, false);
+    /* We need write content access to the parent */
+    access.accessible(parent, privWriteContent, false);
 
     /** Is the parent a calendar collection?
      */



More information about the Bedework-commit mailing list